package com.ruoyi.project.zjsgfa.service;

import java.util.List;
import com.ruoyi.project.zjsgfa.domain.SjFdsgcsTsgj;

/**
 * 设计-分段施工措施_特殊工具Service接口
 * 
 * @author ruoyi
 * @date 2025-08-06
 */
public interface ISjFdsgcsTsgjService 
{
    /**
     * 查询设计-分段施工措施_特殊工具
     * 
     * @param id 设计-分段施工措施_特殊工具主键
     * @return 设计-分段施工措施_特殊工具
     */
    public SjFdsgcsTsgj selectSjFdsgcsTsgjById(Long id);

    /**
     * 查询设计-分段施工措施_特殊工具列表
     * 
     * @param sjFdsgcsTsgj 设计-分段施工措施_特殊工具
     * @return 设计-分段施工措施_特殊工具集合
     */
    public List<SjFdsgcsTsgj> selectSjFdsgcsTsgjList(SjFdsgcsTsgj sjFdsgcsTsgj);

    /**
     * 新增设计-分段施工措施_特殊工具
     * 
     * @param sjFdsgcsTsgj 设计-分段施工措施_特殊工具
     * @return 结果
     */
    public int insertSjFdsgcsTsgj(SjFdsgcsTsgj sjFdsgcsTsgj);

    /**
     * 修改设计-分段施工措施_特殊工具
     * 
     * @param sjFdsgcsTsgj 设计-分段施工措施_特殊工具
     * @return 结果
     */
    public int updateSjFdsgcsTsgj(SjFdsgcsTsgj sjFdsgcsTsgj);

    /**
     * 批量删除设计-分段施工措施_特殊工具
     * 
     * @param ids 需要删除的设计-分段施工措施_特殊工具主键集合
     * @return 结果
     */
    public int deleteSjFdsgcsTsgjByIds(Long[] ids);

    /**
     * 删除设计-分段施工措施_特殊工具信息
     * 
     * @param id 设计-分段施工措施_特殊工具主键
     * @return 结果
     */
    public int deleteSjFdsgcsTsgjById(Long id);
}
